import useUser from "@/hooks/useUser";
import { FieldType, Project } from "@/types";
import {
  Button,
  FormControl,
  HStack,
  IconButton,
  Input,
  Modal,
  ModalBody,
  ModalCloseButton,
  ModalContent,
  ModalFooter,
  ModalHeader,
  ModalOverlay,
  Stack,
  useDisclosure,
  Tag,
  Box,
  Select,
  Textarea,
  Text,
  VStack,
} from "@chakra-ui/react";
import { Fragment } from "react";
import { Control, UseFormRegister, useWatch } from "react-hook-form";
import { FaBrush, FaTrash, FaPencilAlt } from "react-icons/fa";
import {
  NumberInput,
  NumberInputField,
  NumberInputStepper,
  NumberIncrementStepper,
  NumberDecrementStepper,
} from "@chakra-ui/react";

type SceneFieldProps = {
  register: UseFormRegister<Project>;
  parent: string;
  index: number;
  control: Control<Project, any>;
  remove: (index: number) => void;
};

const SceneField = ({
  register,
  parent,
  index,
  control,
  remove,
}: SceneFieldProps) => {
  const { isOpen, onOpen, onClose } = useDisclosure();

  const {
    isOpen: isOpenSelectModal,
    onOpen: onOpenSelectModal,
    onClose: onCloseSelectModal,
  } = useDisclosure();

  const data = useWatch({
    control,
    name: `${parent}.${index}` as any,
  });

  const { isReader } = useUser();

  return (
    <Fragment>
      <FormControl mb={4}>
        <HStack direction="row" align="center" mb={4}>
          <Box>
            <HStack>
              <HStack>
                <Tag>ID: {data.identificator || "N/A"}</Tag>
              </HStack>
              <HStack>
                <Tag>Název: {data.label || "N/A"}</Tag>
              </HStack>
            </HStack>
          </Box>
          {!isReader && (
            <HStack>
              <IconButton
                icon={<FaBrush />}
                onClick={onOpen}
                colorScheme="blue"
                size="xs"
                aria-label="Otevřít menu s úpravami"
              />
              <IconButton
                icon={<FaTrash />}
                colorScheme="red"
                onClick={() => remove(index)}
                size="xs"
                aria-label="Smazat pole"
              />
              {data.type === FieldType.SELECT && (
                <IconButton
                  icon={<FaPencilAlt />}
                  colorScheme="blue"
                  onClick={onOpenSelectModal}
                  size="xs"
                  aria-label="Nastavit hodnoty pro pole s výběrem"
                />
              )}
            </HStack>
          )}
        </HStack>
        {data.type === FieldType.TEXT && (
          <Input
            {...register(`${parent}.${index}.value` as any)}
          />
        )}
        {data.type === FieldType.NUMBER && (
          <NumberInput>
            <NumberInputField
              {...register(`${parent}.${index}.value` as any)}
            />
            <NumberInputStepper>
              <NumberIncrementStepper />
              <NumberDecrementStepper />
            </NumberInputStepper>
          </NumberInput>
        )}
        {data.type === FieldType.SELECT && (
          <Select
            placeholder="Select option"
            {...register(`${parent}.${index}.value` as any)}
          >
            {data.values?.split(";").map((value: string) => (
              <option value={value} key={value}>
                {value}
              </option>
            ))}
          </Select>
        )}
      </FormControl>
      <Modal isOpen={isOpen} onClose={onClose}>
        <ModalOverlay />
        <ModalContent>
          <ModalHeader>Úprava atributu</ModalHeader>
          <ModalCloseButton />
          <ModalBody>
            <Stack>
              <Input
                {...register(`${parent}.${index}.identificator` as any)}
                placeholder="Identifikátor (ID)"
                readOnly={isReader}
              />
              <Input
                {...register(`${parent}.${index}.label` as any)}
                placeholder="Název"
                readOnly={isReader}
              />
            </Stack>
          </ModalBody>
          <ModalFooter>
            <Button colorScheme="blue" mr={3} onClick={onClose}>
              Zavřít
            </Button>
          </ModalFooter>
        </ModalContent>
      </Modal>
      <Modal isOpen={isOpenSelectModal} onClose={onCloseSelectModal}>
        <ModalOverlay />
        <ModalContent>
          <ModalHeader>Úprava seznamu</ModalHeader>
          <ModalCloseButton />
          <ModalBody>
            <VStack spacing={4} align="flex-start">
              <Text fontSize="xs">Hodnoty oddělujte středníkem</Text>
              <Textarea
                {...register(`${parent}.${index}.values` as any)}
                placeholder="Hodnoty oddělené středníkem"
                readOnly={isReader}
              />
            </VStack>
          </ModalBody>
          <ModalFooter>
            <Button colorScheme="blue" mr={3} onClick={onCloseSelectModal}>
              Zavřít
            </Button>
          </ModalFooter>
        </ModalContent>
      </Modal>
    </Fragment>
  );
};

export default SceneField;
