import { Field, FieldType, Layout, Project, Scene, SaveType } from "@/types";
import mongoose, { Model, Schema } from "mongoose";

const fieldSchema = new Schema<Field>({
  id: { type: String },
  name: { type: String },
  type: { type: String, enum: FieldType },
  value: { type: String },
  identificator: { type: String },
  label: { type: String },
  values: { type: String },
});

const layoutSchema = new Schema<Layout>({
  id: { type: String },
  name: { type: String },
  color: { type: String },
  fields: [fieldSchema],
});

const sceneSchema = new Schema<Scene>({
  id: { type: String },
  name: { type: String },
  description: { type: String },
  cols: { type: Number },
  layout: [layoutSchema],
  saveType: { type: String, enum: SaveType, default: SaveType.DEFAULT },
});

const projectSchema = new Schema<Project>({
  name: { type: String },
  description: { type: String },
  scenes: [sceneSchema],
});

export default (mongoose.models.Project as Model<Project>) ||
  mongoose.model<Project>("Project", projectSchema);
