import Auth from "@/components/Auth";
import { CustomAppProps } from "@/types";
import { Alert, AlertIcon, ChakraProvider } from "@chakra-ui/react";
import { SessionProvider } from "next-auth/react";
import { Fragment } from "react";
import { Toaster, resolveValue } from "react-hot-toast";

export default function App({
  Component,
  pageProps: { session, ...pageProps },
}: CustomAppProps) {
  const Layout = Component.layout ?? Fragment;
  const AuthCheck = Component.auth ? Auth : Fragment;

  return (
    <ChakraProvider>
      <SessionProvider session={session}>
        <AuthCheck>
          <Layout>
            <Component {...pageProps} />
            <Toaster position="bottom-right">
              {(t) => (
                <Alert
                  boxShadow="base"
                  style={{
                    width: 384,
                  }}
                  status={t.type === "success" ? "success" : "error"}
                >
                  <AlertIcon />
                  {resolveValue(t.message, t)}
                </Alert>
              )}
            </Toaster>
          </Layout>
        </AuthCheck>
      </SessionProvider>
    </ChakraProvider>
  );
}
