import { useEffect, useState } from "react";
import { Page } from "@/types";
import Layout from "@/components/Layout";
import { useForm } from "react-hook-form";
import useSWR from "swr";
import { useRouter } from "next/router";
import fetcher from "@/utils/fetcher";
import LoadingScreen from "@/components/LoadingScreen";
import { Project } from "@/types";
import toast from "react-hot-toast";
import ProjectForm from "@/components/ProjectForm";

const Project: Page = () => {
  const router = useRouter();

  const { data, isLoading } = useSWR(
    `/api/projects/${router.query.id}`,
    fetcher
  );

  const { register, handleSubmit, reset, control } = useForm<Project>();

  const [isSubmitLoading, setIsSubmitLoading] = useState(false);

  const onSubmit = async (data: Project) => {
    setIsSubmitLoading(true);
    await fetch(`/api/projects/${router.query.id}`, {
      method: "POST",
      body: JSON.stringify(data),
      headers: { "Content-Type": "application/json" },
    });
    toast.success("Projekt byl úspěšně uložen");
    setIsSubmitLoading(false);
  };

  // useInterval(() => {
  //   refSubmitButton?.current?.click();
  // }, 10000);

  useEffect(() => {
    reset(data);
  }, [data, reset]);

  if (isLoading) return <LoadingScreen />;

  return (
    <ProjectForm
      onSubmit={handleSubmit(onSubmit)}
      control={control}
      register={register}
      isLoading={isSubmitLoading}
    />
  );
};

Project.auth = true;
Project.layout = Layout;
export default Project;
