import {
  Card,
  Heading,
  Button,
  CardHeader,
  Thead,
  Tbody,
  Tr,
  TableContainer,
  Th,
  Table,
  Td,
  IconButton,
} from "@chakra-ui/react";
import { Page } from "@/types";
import Link from "next/link";
import Layout from "@/components/Layout";
import fetcher from "@/utils/fetcher";
import useSWR, { mutate } from "swr";
import { Project } from "@/types";
import LoadingScreen from "@/components/LoadingScreen";
import { FaTrash } from "react-icons/fa";
import {
  AlertDialog,
  AlertDialogBody,
  AlertDialogFooter,
  AlertDialogHeader,
  AlertDialogContent,
  AlertDialogOverlay,
  useDisclosure,
} from "@chakra-ui/react";
import { useRef, useState } from "react";
import toast from "react-hot-toast";
import useUser from "@/hooks/useUser";

const Projects: Page = () => {
  const { data, isLoading } = useSWR("/api/projects", fetcher);

  const { isOpen, onOpen, onClose } = useDisclosure();
  const cancelRef = useRef<HTMLButtonElement | null>(null);

  const [activeId, setActiveId] = useState<string | null>(null);

  const { isEditor, isAdmin, isReader } = useUser();

  if (isLoading) return <LoadingScreen />;

  const deleteProject = async () => {
    const res = await fetch(`/api/projects/${activeId}`, {
      method: "DELETE",
    });
    if (res.ok) {
      onClose();
      mutate("/api/projects");
      toast.success("Projekt byl úspěšně smazán.");
    }
  };

  return (
    <Card>
      <CardHeader>
        <Heading size="md" marginBottom={4}>
          Projekty
        </Heading>
        <Link href="/admin/projects/new">
          {!isReader && (
            <Button colorScheme="blue" size="sm">
              Přidat projekt
            </Button>
          )}
        </Link>
      </CardHeader>
      <TableContainer>
        <Table variant="simple">
          <Thead>
            <Tr>
              <Th>Jméno projektu</Th>
              <Th>Akce</Th>
            </Tr>
          </Thead>
          <Tbody>
            {data?.map((project: Project) => (
              <Tr key={project.name}>
                <Td>
                  <Link href={`/admin/projects/${project._id}`}>
                    <Button colorScheme="blue" variant="link">
                      {project.name}
                    </Button>
                  </Link>
                </Td>
                <Td>
                  {(isEditor || isAdmin) && (
                    <IconButton
                      colorScheme="red"
                      aria-label="Smazat projekt"
                      size="sm"
                      onClick={() => {
                        setActiveId(project._id);
                        onOpen();
                      }}
                      icon={<FaTrash />}
                    />
                  )}
                </Td>
              </Tr>
            ))}
          </Tbody>
        </Table>
      </TableContainer>
      <AlertDialog
        isOpen={isOpen}
        leastDestructiveRef={cancelRef}
        onClose={onClose}
      >
        <AlertDialogOverlay>
          <AlertDialogContent>
            <AlertDialogHeader fontSize="lg" fontWeight="bold">
              Smazat projekt
            </AlertDialogHeader>

            <AlertDialogBody>
              Jste si jisti? Tuto akci nelze vrátit zpět.
            </AlertDialogBody>

            <AlertDialogFooter>
              <Button ref={cancelRef} onClick={onClose}>
                Zrušit
              </Button>
              <Button colorScheme="red" onClick={deleteProject} ml={3}>
                Smazat
              </Button>
            </AlertDialogFooter>
          </AlertDialogContent>
        </AlertDialogOverlay>
      </AlertDialog>
    </Card>
  );
};

Projects.auth = true;
Projects.layout = Layout;
export default Projects;
