import { useState } from "react";
import { Page } from "@/types";
import Layout from "@/components/Layout";
import { useForm } from "react-hook-form";
import { Project } from "@/types";
import ProjectForm from "@/components/ProjectForm";
import toast from "react-hot-toast";
import { useRouter } from "next/router";

const Project: Page = () => {
  const { register, handleSubmit, control } = useForm<Project>();

  const router = useRouter();

  const [isSubmitLoading, setIsSubmitLoading] = useState(false);

  const onSubmit = async (data: Project) => {
    setIsSubmitLoading(true);
    const res = await fetch("/api/projects/new", {
      method: "POST",
      body: JSON.stringify(data),
      headers: { "Content-Type": "application/json" },
    });
    const { _id } = await res.json();
    toast.success("Projekt byl úspěšně vytvořen");
    setIsSubmitLoading(false);
    router.push(`/admin/projects/${_id}`);
  };

  return (
    <ProjectForm
      onSubmit={handleSubmit(onSubmit)}
      control={control}
      register={register}
      isLoading={isSubmitLoading}
    />
  );
};

Project.auth = true;
Project.layout = Layout;
export default Project;
