import Layout from "@/components/Layout";
import { Page } from "@/types";
import fetcher from "@/utils/fetcher";
import {
  Button,
  Card,
  CardBody,
  CardFooter,
  CardHeader,
  Divider,
  FormControl,
  FormLabel,
  Heading,
  Input,
  Select,
  Stack,
} from "@chakra-ui/react";
import { useRouter } from "next/router";
import { useEffect, useState } from "react";
import { useForm } from "react-hook-form";
import toast from "react-hot-toast";
import useSWR from "swr";

type Inputs = {
  firstName: string;
  lastName: string;
  email: string;
  role: string;
};

const EditUser: Page = () => {
  const { register, handleSubmit, reset } = useForm<Inputs>();
  const [loading, setLoading] = useState(false);

  const onSubmit = async (data: Inputs) => {
    setLoading(true);
    const res = await fetch(`/api/users/${router.query.id}`, {
      method: "POST",
      body: JSON.stringify(data),
      headers: { "Content-Type": "application/json" },
    });
    if (res.ok) setLoading(false);
  };

  const router = useRouter();

  const { data, mutate } = useSWR(`/api/users/${router.query.id}`, fetcher);

  useEffect(() => {
    reset(data);
  }, [data, reset]);

  const deleteUser = async () => {
    await fetch(`/api/users/${router.query.id}`, {
      method: "DELETE",
    });

    router.push("/admin/users");
    toast.success("Uživatel byl smazán");
    mutate();
  };

  return (
    <Card as="form" onSubmit={handleSubmit(onSubmit)}>
      <CardHeader>
        <Heading size="md">Upravit uživatele</Heading>
      </CardHeader>
      <CardBody>
        <Stack spacing="5">
          <FormControl isReadOnly>
            <FormLabel htmlFor="firstName">Jméno</FormLabel>
            <Input id="firstName" type="text" {...register("firstName")} />
          </FormControl>
          <FormControl isReadOnly>
            <FormLabel htmlFor="lastName">Přijmení</FormLabel>
            <Input id="lastName" type="text" {...register("lastName")} />
          </FormControl>
          <Divider />
          <FormControl isReadOnly>
            <FormLabel htmlFor="email">E-mailová adresa</FormLabel>
            <Input id="email" type="email" {...register("email")} />
          </FormControl>
          <Divider />
          <FormControl isRequired>
            <FormLabel htmlFor="email">Role</FormLabel>
            <Select placeholder="Zvol roli" {...register("role")}>
              <option value="admin">Administrátor</option>
              <option value="editor">Editor</option>
              <option value="reader">Čtenář</option>
            </Select>
          </FormControl>
        </Stack>
      </CardBody>
      <CardFooter gap={2}>
        <Button type="submit" isLoading={loading} colorScheme="blue">
          Uložit uživatele
        </Button>
        <Button
          type="button"
          onClick={deleteUser}
          isLoading={loading}
          colorScheme="red"
        >
          Smazat uživatele
        </Button>
      </CardFooter>
    </Card>
  );
};

EditUser.auth = true;
EditUser.layout = Layout;
export default EditUser;
