import Layout from "@/components/Layout";
import LoadingScreen from "@/components/LoadingScreen";
import { User } from "@/models/User";
import { Page } from "@/types";
import fetcher from "@/utils/fetcher";
import {
  Button,
  Card,
  CardHeader,
  Heading,
  Table,
  TableContainer,
  Tag,
  Tbody,
  Td,
  Th,
  Thead,
  Tr,
} from "@chakra-ui/react";
import Link from "next/link";
import useSWR from "swr";

const Users: Page = () => {
  const { data, isLoading } = useSWR("/api/users", fetcher);

  if (isLoading) return <LoadingScreen />;

  return (
    <Card>
      <CardHeader>
        <Heading size="md" marginBottom={4}>
          Uživatelé
        </Heading>
        <Link href="/admin/users/new">
          <Button colorScheme="blue" size="sm">
            Přidat uživatele
          </Button>
        </Link>
      </CardHeader>
      <TableContainer>
        <Table variant="simple">
          <Thead>
            <Tr>
              <Th>Jméno uživatele</Th>
              <Th>E-mail uživatele</Th>
              <Th>Role</Th>
            </Tr>
          </Thead>
          <Tbody>
            {data?.map((user: User) => (
              <Tr key={user.email}>
                <Td>
                  <Link href={`/admin/users/${user._id}`}>
                    <Button colorScheme="blue" variant="link">
                      {user.firstName} {user.lastName}
                    </Button>
                  </Link>
                </Td>
                <Td>{user.email}</Td>
                <Td>
                  <Tag>{user.role}</Tag>
                </Td>
              </Tr>
            ))}
          </Tbody>
        </Table>
      </TableContainer>
    </Card>
  );
};

Users.auth = true;
Users.layout = Layout;
export default Users;
