import Layout from "@/components/Layout";
import { PasswordField } from "@/components/PasswordField";
import { Page } from "@/types";
import {
  Button,
  Card,
  CardBody,
  CardFooter,
  CardHeader,
  Divider,
  FormControl,
  FormLabel,
  Heading,
  Input,
  Stack,
} from "@chakra-ui/react";
import { useRouter } from "next/router";
import { useState } from "react";
import { useForm } from "react-hook-form";

type Inputs = {
  email: string;
  password: string;
  repeatPassword: string;
  firstName: string;
  lastName: string;
};

const NewUser: Page = () => {
  const {
    register,
    handleSubmit,
    watch,
    formState: { errors },
  } = useForm<Inputs>();
  const [loading, setLoading] = useState(false);

  const router = useRouter();

  const onSubmit = async (data: Inputs) => {
    setLoading(true);
    const res = await fetch("/api/auth/sign-up", {
      method: "POST",
      body: JSON.stringify(data),
      headers: { "Content-Type": "application/json" },
    });
    if (res.ok) {
      router.push("/admin/users");
    }
    setLoading(false);
  };

  return (
    <Card as="form" onSubmit={handleSubmit(onSubmit)}>
      <CardHeader>
        <Heading size="md" marginBottom={4}>
          Založit uživatele
        </Heading>
      </CardHeader>
      <CardBody>
        <Stack spacing="5">
          <FormControl>
            <FormLabel htmlFor="firstName">Jméno</FormLabel>
            <Input id="firstName" type="text" {...register("firstName")} />
          </FormControl>
          <FormControl>
            <FormLabel htmlFor="lastName">Přijmení</FormLabel>
            <Input id="lastName" type="text" {...register("lastName")} />
          </FormControl>
          <Divider />
          <FormControl isRequired>
            <FormLabel htmlFor="email">E-mailová adresa</FormLabel>
            <Input
              id="email"
              type="email"
              {...register("email", {
                required: "Pole je vyžadováno",
              })}
            />
          </FormControl>
          <Divider />
          <PasswordField
            {...register("password", {
              required: "Pole je vyžadováno",
            })}
          />
          <PasswordField
            {...register("repeatPassword", {
              required: "Pole je vyžadováno",
            })}
          />
        </Stack>
      </CardBody>
      <CardFooter>
        <Button type="submit" isLoading={loading}>
          Založit uživatele
        </Button>
      </CardFooter>
    </Card>
  );
};

NewUser.auth = true;
NewUser.layout = Layout;
export default NewUser;
