import clientPromise from "@/lib/dbClient";
import dbConnect from "@/lib/mongooseClient";
import User from "@/models/User";
import hashPassword from "@/utils/hashPassword";
import { MongoDBAdapter } from "@auth/mongodb-adapter";
import NextAuth, { AuthOptions } from "next-auth";
import CredentialsProvider from "next-auth/providers/credentials";

export const authOptions: AuthOptions = {
  adapter: MongoDBAdapter(clientPromise),
  providers: [
    CredentialsProvider({
      credentials: {
        email: { type: "text" },
        password: { type: "password" },
      },
      async authorize(credentials, req) {
        await dbConnect();
        const user = await User.findOne({
          email: credentials?.email,
        });
        if (user) {
          const hashedPassword = hashPassword(credentials?.password!);
          if (user.password === hashedPassword) {
            return user;
          } else {
            throw new Error("PasswordNotMatch");
          }
        } else {
          throw new Error("UserNotFound");
        }
      },
    }),
  ],
  secret: process.env.NEXTAUTH_SECRET,
  session: {
    strategy: "jwt",
  },
  callbacks: {
    async session({ session, token }) {
      await dbConnect();
      const email = token.email;

      const user = await User.findOne({ email: email }).select(
        "-password -verificationToken"
      );
      session.user = user;

      return session;
    },
  },
};

export default NextAuth(authOptions);
