import dbConnect from "@/lib/mongooseClient";
import Project from "@/models/Project";
import { BoxType, SaveType } from "@/types";
import type { NextApiRequest, NextApiResponse } from "next";

const handler = async (req: NextApiRequest, res: NextApiResponse) => {
  await dbConnect();
  const projectId = req.query.id;
  const sceneId = req.query.scene;
  if (!projectId || !sceneId) {
    res.status(400).json({ message: "Missing projectId or sceneId" });
  }
  const project = await Project.findById(projectId);

  if (!project)
    return res
      .status(404)
      .json({
        message:
          "Project not found. Are you sure you entered the correct project ID?",
      });

  const scene = project.scenes.find((scene) => scene.id === sceneId);

  if (!scene)
    return res
      .status(404)
      .json({ message: "Scene not found. Are you sure you saved the scene?" });

  let data;

  // Save type not set in DB, set default one
  const saveType = scene.saveType ?? SaveType.DEFAULT;

  if (saveType === SaveType.DEFAULT) {
    data = Array(
      scene.layout?.reduce((accumulator: Record<string, string>, box) => {
        box.fields.forEach((field) => {
          accumulator[field.identificator] = field.value;
        });
        return accumulator;
      }, {})
    );
  }

  if (saveType === SaveType.ITERATED) {
    data = scene.layout?.map((box: BoxType) => {
      const result: Record<string, string> = {};
      box.fields.forEach((field) => {
        result[field.identificator] = field.value;
      });

      return result;
    });
  }

  res.status(200).json(data);
};

export default handler;
