import {
  Box,
  Button,
  Card,
  CardBody,
  Container,
  FormControl,
  FormLabel,
  Heading,
  Input,
  Stack,
} from "@chakra-ui/react";
import { PasswordField } from "@/components/PasswordField";
import { useForm } from "react-hook-form";
import { signIn } from "next-auth/react";
import useSWR from "swr";
import fetcher from "@/utils/fetcher";
import { useRouter } from "next/router";
import LoadingScreen from "@/components/LoadingScreen";
import { useState } from "react";

type Inputs = {
  email: string;
  password: string;
};

const App = () => {
  const router = useRouter();
  const { data, error, isLoading } = useSWR("/api/users/init-check", fetcher);
  const [isSignIn, setIsSignIn] = useState(false);
  const { register, handleSubmit } = useForm<Inputs>();

  const onSubmit = async (data: Inputs) => {
    setIsSignIn(true);
    await signIn("credentials", {
      email: data.email,
      password: data.password,
      callbackUrl: "/admin/projects",
    });
    setIsSignIn(false);
  };

  if (data === false) router.push("/auth/sign-up");

  if (isLoading) return <LoadingScreen />;

  return (
    <Box bgColor="gray.50" minHeight="100vh">
      <Container
        maxW="lg"
        py={{ base: "12", md: "24" }}
        px={{ base: "0", sm: "8" }}
      >
        <Stack spacing="8">
          <Stack spacing="6" alignItems="center">
            <Stack spacing={{ base: "2", md: "3" }} textAlign="center">
              <Heading size="md">Přihlášení</Heading>
            </Stack>
          </Stack>
          <Card>
            <CardBody sx={{ p: 8 }}>
              <Stack spacing="6" as="form" onSubmit={handleSubmit(onSubmit)}>
                <Stack spacing="5">
                  <FormControl>
                    <FormLabel htmlFor="email">E-mailová adresa</FormLabel>
                    <Input
                      id="email"
                      type="email"
                      {...register("email", {
                        required: "Pole je vyžadováno",
                      })}
                    />
                  </FormControl>
                  <PasswordField
                    {...register("password", {
                      required: "Pole je vyžadováno",
                    })}
                  />
                </Stack>
                {/* <HStack justify="space-between">
                  <Button variant="text" size="sm">
                    Zapomenuté heslo
                  </Button>
                </HStack> */}
                <Stack spacing="6">
                  <Button type="submit" colorScheme="blue" isLoading={isSignIn}>
                    Přihlásit se
                  </Button>
                </Stack>
              </Stack>
            </CardBody>
          </Card>
        </Stack>
      </Container>
    </Box>
  );
};

export default App;
