import { NextPage } from "next";
import type { ReactElement, ReactNode } from "react";

import Layout from "@/components/Layout";
import { AppProps } from "next/app";

export interface CustomAppProps extends Omit<AppProps, "Component"> {
  Component: AppProps["Component"] & {
    layout?: typeof Layout;
    auth?: boolean;
    getLayout?: (page: ReactElement) => ReactNode;
  };
}

export type Page<P = {}> = NextPage<P> & {
  layout?: typeof Layout;
  auth?: boolean;
};

export type BoxType = {
  id: string;
  name: string;
  fields: any[];
};

export type SceneType = {
  name: string;
  id: string;
  layout?: [BoxType];
  saveType: SaveType;
};

export type ProjectInputs = {
  name: string;
  scenes: SceneType[];
};

export enum FieldType {
  TEXT = "text",
  NUMBER = "number",
  SELECT = "select",
  DATE = "date",
  IMAGE = "image",
}

export enum SaveType {
  DEFAULT = "default",
  ITERATED = "iterated",
}

export type Field = {
  id: string;
  name: string;
  type: FieldType;
  label: string;
  value: string;
  identificator: string;
  values: string;
};

export type Layout = {
  id: string;
  name: string;
  color: string;
  fields: Field[];
};

export type Scene = {
  id?: string;
  name: string;
  description: string;
  cols: number;
  layout?: Layout[];
  saveType: SaveType;
};

export interface Project {
  _id: string;
  name: string;
  description: string;
  scenes: Scene[];
  createdAt: string | Date;
}
